# -*- coding: utf-8 -*-

################################################################################
## Form generated from reading UI file 'Ui_DTSetting.ui'
##
## Created by: Qt User Interface Compiler version 5.15.2
##
## WARNING! All changes made in this file will be lost when recompiling UI file!
################################################################################

from PySide2.QtCore import *
from PySide2.QtGui import *
from PySide2.QtWidgets import *

from DTPySide.DTWidget.DTApplyButton import DTApplyButton
from DTPySide.DTWidget import LazyCombobox

import DTPySide.DT_rc

class Ui_DTSetting(object):
    def setupUi(self, DTSetting):
        if not DTSetting.objectName():
            DTSetting.setObjectName(u"DTSetting")
        DTSetting.resize(976, 666)
        self.horizontalLayout = QHBoxLayout(DTSetting)
        self.horizontalLayout.setObjectName(u"horizontalLayout")
        self.horizontalLayout.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_buttons = QVBoxLayout()
        self.verticalLayout_buttons.setObjectName(u"verticalLayout_buttons")
        self.verticalSpacer_buttons = QSpacerItem(20, 40, QSizePolicy.Minimum, QSizePolicy.Expanding)

        self.verticalLayout_buttons.addItem(self.verticalSpacer_buttons)


        self.horizontalLayout.addLayout(self.verticalLayout_buttons)

        self.stackedWidget = QStackedWidget(DTSetting)
        self.stackedWidget.setObjectName(u"stackedWidget")
        self.page_basicinfo = QWidget()
        self.page_basicinfo.setObjectName(u"page_basicinfo")
        self.horizontalLayout_2 = QHBoxLayout(self.page_basicinfo)
        self.horizontalLayout_2.setSpacing(0)
        self.horizontalLayout_2.setObjectName(u"horizontalLayout_2")
        self.horizontalLayout_2.setContentsMargins(0, 0, 0, 0)
        self.scrollAreaBasicInfo = QScrollArea(self.page_basicinfo)
        self.scrollAreaBasicInfo.setObjectName(u"scrollAreaBasicInfo")
        self.scrollAreaBasicInfo.setFrameShape(QFrame.NoFrame)
        self.scrollAreaBasicInfo.setWidgetResizable(True)
        self.scrollAreaWidgetContentsBasicInfo = QWidget()
        self.scrollAreaWidgetContentsBasicInfo.setObjectName(u"scrollAreaWidgetContentsBasicInfo")
        self.scrollAreaWidgetContentsBasicInfo.setGeometry(QRect(0, 0, 948, 666))
        self.gridLayout = QGridLayout(self.scrollAreaWidgetContentsBasicInfo)
        self.gridLayout.setObjectName(u"gridLayout")
        self.gridLayout.setContentsMargins(0, 0, 15, 0)
        self.lineEdit_password = QLineEdit(self.scrollAreaWidgetContentsBasicInfo)
        self.lineEdit_password.setObjectName(u"lineEdit_password")

        self.gridLayout.addWidget(self.lineEdit_password, 1, 0, 1, 1)

        self.label_font = QLabel(self.scrollAreaWidgetContentsBasicInfo)
        self.label_font.setObjectName(u"label_font")

        self.gridLayout.addWidget(self.label_font, 6, 0, 1, 1)

        self.pushButton_backup = DTApplyButton(self.scrollAreaWidgetContentsBasicInfo)
        self.pushButton_backup.setObjectName(u"pushButton_backup")
        sizePolicy = QSizePolicy(QSizePolicy.Fixed, QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_backup.sizePolicy().hasHeightForWidth())
        self.pushButton_backup.setSizePolicy(sizePolicy)

        self.gridLayout.addWidget(self.pushButton_backup, 5, 1, 1, 1)

        self.gridLayout_2 = QGridLayout()
        self.gridLayout_2.setObjectName(u"gridLayout_2")
        self.horizontalSpacer_2 = QSpacerItem(40, 20, QSizePolicy.Expanding, QSizePolicy.Minimum)

        self.gridLayout_2.addItem(self.horizontalSpacer_2, 2, 3, 1, 1)

        self.horizontalSpacer_3 = QSpacerItem(40, 20, QSizePolicy.Expanding, QSizePolicy.Minimum)

        self.gridLayout_2.addItem(self.horizontalSpacer_3, 4, 3, 1, 1)

        self.label_contrast = QLabel(self.scrollAreaWidgetContentsBasicInfo)
        self.label_contrast.setObjectName(u"label_contrast")

        self.gridLayout_2.addWidget(self.label_contrast, 6, 1, 1, 1)

        self.horizontalSpacer_4 = QSpacerItem(40, 20, QSizePolicy.Expanding, QSizePolicy.Minimum)

        self.gridLayout_2.addItem(self.horizontalSpacer_4, 6, 3, 1, 1)

        self.slider_Hue = QSlider(self.scrollAreaWidgetContentsBasicInfo)
        self.slider_Hue.setObjectName(u"slider_Hue")
        self.slider_Hue.setMaximum(360)
        self.slider_Hue.setOrientation(Qt.Horizontal)

        self.gridLayout_2.addWidget(self.slider_Hue, 1, 1, 1, 3)

        self.slider_contrast = QSlider(self.scrollAreaWidgetContentsBasicInfo)
        self.slider_contrast.setObjectName(u"slider_contrast")
        self.slider_contrast.setMaximum(500)
        self.slider_contrast.setPageStep(1)
        self.slider_contrast.setOrientation(Qt.Horizontal)

        self.gridLayout_2.addWidget(self.slider_contrast, 7, 1, 1, 3)

        self.slider_saturation = QSlider(self.scrollAreaWidgetContentsBasicInfo)
        self.slider_saturation.setObjectName(u"slider_saturation")
        self.slider_saturation.setMaximum(500)
        self.slider_saturation.setPageStep(1)
        self.slider_saturation.setOrientation(Qt.Horizontal)

        self.gridLayout_2.addWidget(self.slider_saturation, 3, 1, 1, 3)

        self.label_luminance = QLabel(self.scrollAreaWidgetContentsBasicInfo)
        self.label_luminance.setObjectName(u"label_luminance")

        self.gridLayout_2.addWidget(self.label_luminance, 4, 1, 1, 1)

        self.pushButton_hue_reset = QPushButton(self.scrollAreaWidgetContentsBasicInfo)
        self.pushButton_hue_reset.setObjectName(u"pushButton_hue_reset")
        sizePolicy.setHeightForWidth(self.pushButton_hue_reset.sizePolicy().hasHeightForWidth())
        self.pushButton_hue_reset.setSizePolicy(sizePolicy)

        self.gridLayout_2.addWidget(self.pushButton_hue_reset, 0, 2, 1, 1)

        self.pushButton_luminance_reset = QPushButton(self.scrollAreaWidgetContentsBasicInfo)
        self.pushButton_luminance_reset.setObjectName(u"pushButton_luminance_reset")
        sizePolicy.setHeightForWidth(self.pushButton_luminance_reset.sizePolicy().hasHeightForWidth())
        self.pushButton_luminance_reset.setSizePolicy(sizePolicy)

        self.gridLayout_2.addWidget(self.pushButton_luminance_reset, 4, 2, 1, 1)

        self.pushButton_saturation_reset = QPushButton(self.scrollAreaWidgetContentsBasicInfo)
        self.pushButton_saturation_reset.setObjectName(u"pushButton_saturation_reset")
        sizePolicy.setHeightForWidth(self.pushButton_saturation_reset.sizePolicy().hasHeightForWidth())
        self.pushButton_saturation_reset.setSizePolicy(sizePolicy)

        self.gridLayout_2.addWidget(self.pushButton_saturation_reset, 2, 2, 1, 1)

        self.horizontalSpacer = QSpacerItem(40, 20, QSizePolicy.Expanding, QSizePolicy.Minimum)

        self.gridLayout_2.addItem(self.horizontalSpacer, 0, 3, 1, 1)

        self.slider_luminance = QSlider(self.scrollAreaWidgetContentsBasicInfo)
        self.slider_luminance.setObjectName(u"slider_luminance")
        self.slider_luminance.setMaximum(500)
        self.slider_luminance.setPageStep(1)
        self.slider_luminance.setOrientation(Qt.Horizontal)

        self.gridLayout_2.addWidget(self.slider_luminance, 5, 1, 1, 3)

        self.label_saturation = QLabel(self.scrollAreaWidgetContentsBasicInfo)
        self.label_saturation.setObjectName(u"label_saturation")

        self.gridLayout_2.addWidget(self.label_saturation, 2, 1, 1, 1)

        self.label_hue = QLabel(self.scrollAreaWidgetContentsBasicInfo)
        self.label_hue.setObjectName(u"label_hue")

        self.gridLayout_2.addWidget(self.label_hue, 0, 1, 1, 1)

        self.pushButton_contrast_reset = QPushButton(self.scrollAreaWidgetContentsBasicInfo)
        self.pushButton_contrast_reset.setObjectName(u"pushButton_contrast_reset")
        sizePolicy.setHeightForWidth(self.pushButton_contrast_reset.sizePolicy().hasHeightForWidth())
        self.pushButton_contrast_reset.setSizePolicy(sizePolicy)

        self.gridLayout_2.addWidget(self.pushButton_contrast_reset, 6, 2, 1, 1)

        self.checkBox_reverse = QCheckBox(self.scrollAreaWidgetContentsBasicInfo)
        self.checkBox_reverse.setObjectName(u"checkBox_reverse")

        self.gridLayout_2.addWidget(self.checkBox_reverse, 4, 0, 1, 1)


        self.gridLayout.addLayout(self.gridLayout_2, 14, 0, 1, 1)

        self.lineEdit_data_dir = QLineEdit(self.scrollAreaWidgetContentsBasicInfo)
        self.lineEdit_data_dir.setObjectName(u"lineEdit_data_dir")
        self.lineEdit_data_dir.setReadOnly(True)

        self.gridLayout.addWidget(self.lineEdit_data_dir, 3, 0, 1, 1)

        self.pushButton_data_dir = DTApplyButton(self.scrollAreaWidgetContentsBasicInfo)
        self.pushButton_data_dir.setObjectName(u"pushButton_data_dir")
        sizePolicy.setHeightForWidth(self.pushButton_data_dir.sizePolicy().hasHeightForWidth())
        self.pushButton_data_dir.setSizePolicy(sizePolicy)

        self.gridLayout.addWidget(self.pushButton_data_dir, 3, 1, 1, 1)

        self.comboBox_language = LazyCombobox(self.scrollAreaWidgetContentsBasicInfo)
        self.comboBox_language.setObjectName(u"comboBox_language")
        sizePolicy1 = QSizePolicy(QSizePolicy.Preferred, QSizePolicy.Preferred)
        sizePolicy1.setHorizontalStretch(0)
        sizePolicy1.setVerticalStretch(0)
        sizePolicy1.setHeightForWidth(self.comboBox_language.sizePolicy().hasHeightForWidth())
        self.comboBox_language.setSizePolicy(sizePolicy1)

        self.gridLayout.addWidget(self.comboBox_language, 16, 0, 1, 1)

        self.lineEdit_backup = QLineEdit(self.scrollAreaWidgetContentsBasicInfo)
        self.lineEdit_backup.setObjectName(u"lineEdit_backup")
        self.lineEdit_backup.setReadOnly(True)

        self.gridLayout.addWidget(self.lineEdit_backup, 5, 0, 1, 1)

        self.label_scale = QLabel(self.scrollAreaWidgetContentsBasicInfo)
        self.label_scale.setObjectName(u"label_scale")

        self.gridLayout.addWidget(self.label_scale, 8, 0, 1, 1)

        self.label_window_effect = QLabel(self.scrollAreaWidgetContentsBasicInfo)
        self.label_window_effect.setObjectName(u"label_window_effect")

        self.gridLayout.addWidget(self.label_window_effect, 10, 0, 1, 1)

        self.label_language = QLabel(self.scrollAreaWidgetContentsBasicInfo)
        self.label_language.setObjectName(u"label_language")

        self.gridLayout.addWidget(self.label_language, 15, 0, 1, 1)

        self.label_data_dir = QLabel(self.scrollAreaWidgetContentsBasicInfo)
        self.label_data_dir.setObjectName(u"label_data_dir")

        self.gridLayout.addWidget(self.label_data_dir, 2, 0, 1, 1)

        self.comboBox_country = LazyCombobox(self.scrollAreaWidgetContentsBasicInfo)
        self.comboBox_country.setObjectName(u"comboBox_country")
        sizePolicy1.setHeightForWidth(self.comboBox_country.sizePolicy().hasHeightForWidth())
        self.comboBox_country.setSizePolicy(sizePolicy1)

        self.gridLayout.addWidget(self.comboBox_country, 18, 0, 1, 1)

        self.comboBox_window_effect = LazyCombobox(self.scrollAreaWidgetContentsBasicInfo)
        self.comboBox_window_effect.addItem("")
        self.comboBox_window_effect.addItem("")
        self.comboBox_window_effect.addItem("")
        self.comboBox_window_effect.setObjectName(u"comboBox_window_effect")
        sizePolicy1.setHeightForWidth(self.comboBox_window_effect.sizePolicy().hasHeightForWidth())
        self.comboBox_window_effect.setSizePolicy(sizePolicy1)

        self.gridLayout.addWidget(self.comboBox_window_effect, 11, 0, 1, 1)

        self.verticalSpacer = QSpacerItem(20, 258, QSizePolicy.Minimum, QSizePolicy.Expanding)

        self.gridLayout.addItem(self.verticalSpacer, 19, 1, 1, 1)

        self.label_backup = QLabel(self.scrollAreaWidgetContentsBasicInfo)
        self.label_backup.setObjectName(u"label_backup")

        self.gridLayout.addWidget(self.label_backup, 4, 0, 1, 1)

        self.label_password = QLabel(self.scrollAreaWidgetContentsBasicInfo)
        self.label_password.setObjectName(u"label_password")

        self.gridLayout.addWidget(self.label_password, 0, 0, 1, 1)

        self.pushButton_scale = DTApplyButton(self.scrollAreaWidgetContentsBasicInfo)
        self.pushButton_scale.setObjectName(u"pushButton_scale")
        sizePolicy.setHeightForWidth(self.pushButton_scale.sizePolicy().hasHeightForWidth())
        self.pushButton_scale.setSizePolicy(sizePolicy)

        self.gridLayout.addWidget(self.pushButton_scale, 9, 1, 1, 1)

        self.label_theme = QLabel(self.scrollAreaWidgetContentsBasicInfo)
        self.label_theme.setObjectName(u"label_theme")

        self.gridLayout.addWidget(self.label_theme, 12, 0, 1, 1)

        self.pushButton_font = QPushButton(self.scrollAreaWidgetContentsBasicInfo)
        self.pushButton_font.setObjectName(u"pushButton_font")
        sizePolicy2 = QSizePolicy(QSizePolicy.Minimum, QSizePolicy.Fixed)
        sizePolicy2.setHorizontalStretch(0)
        sizePolicy2.setVerticalStretch(0)
        sizePolicy2.setHeightForWidth(self.pushButton_font.sizePolicy().hasHeightForWidth())
        self.pushButton_font.setSizePolicy(sizePolicy2)

        self.gridLayout.addWidget(self.pushButton_font, 7, 0, 1, 1)

        self.comboBox_theme = LazyCombobox(self.scrollAreaWidgetContentsBasicInfo)
        self.comboBox_theme.setObjectName(u"comboBox_theme")
        sizePolicy1.setHeightForWidth(self.comboBox_theme.sizePolicy().hasHeightForWidth())
        self.comboBox_theme.setSizePolicy(sizePolicy1)

        self.gridLayout.addWidget(self.comboBox_theme, 13, 0, 1, 1)

        self.label_country = QLabel(self.scrollAreaWidgetContentsBasicInfo)
        self.label_country.setObjectName(u"label_country")

        self.gridLayout.addWidget(self.label_country, 17, 0, 1, 1)

        self.spinBox_scale = QDoubleSpinBox(self.scrollAreaWidgetContentsBasicInfo)
        self.spinBox_scale.setObjectName(u"spinBox_scale")
        self.spinBox_scale.setDecimals(1)
        self.spinBox_scale.setMinimum(1.000000000000000)
        self.spinBox_scale.setMaximum(10.000000000000000)
        self.spinBox_scale.setSingleStep(0.100000000000000)

        self.gridLayout.addWidget(self.spinBox_scale, 9, 0, 1, 1)

        self.verticalLayout_color = QVBoxLayout()
        self.verticalLayout_color.setSpacing(0)
        self.verticalLayout_color.setObjectName(u"verticalLayout_color")
        self.verticalLayout_color.setContentsMargins(-1, 34, -1, 5)
        self.label_color_preview = QLabel(self.scrollAreaWidgetContentsBasicInfo)
        self.label_color_preview.setObjectName(u"label_color_preview")
        sizePolicy.setHeightForWidth(self.label_color_preview.sizePolicy().hasHeightForWidth())
        self.label_color_preview.setSizePolicy(sizePolicy)
        self.label_color_preview.setMinimumSize(QSize(26, 26))
        self.label_color_preview.setMaximumSize(QSize(26, 26))
        self.label_color_preview.setAlignment(Qt.AlignCenter)

        self.verticalLayout_color.addWidget(self.label_color_preview)

        self.verticalSpacer_2 = QSpacerItem(20, 40, QSizePolicy.Minimum, QSizePolicy.Expanding)

        self.verticalLayout_color.addItem(self.verticalSpacer_2)

        self.pushButton_color = DTApplyButton(self.scrollAreaWidgetContentsBasicInfo)
        self.pushButton_color.setObjectName(u"pushButton_color")
        sizePolicy.setHeightForWidth(self.pushButton_color.sizePolicy().hasHeightForWidth())
        self.pushButton_color.setSizePolicy(sizePolicy)

        self.verticalLayout_color.addWidget(self.pushButton_color)


        self.gridLayout.addLayout(self.verticalLayout_color, 14, 1, 1, 1)

        self.scrollAreaBasicInfo.setWidget(self.scrollAreaWidgetContentsBasicInfo)

        self.horizontalLayout_2.addWidget(self.scrollAreaBasicInfo)

        self.stackedWidget.addWidget(self.page_basicinfo)

        self.horizontalLayout.addWidget(self.stackedWidget)


        self.retranslateUi(DTSetting)

        self.stackedWidget.setCurrentIndex(0)


        QMetaObject.connectSlotsByName(DTSetting)
    # setupUi

    def retranslateUi(self, DTSetting):
        DTSetting.setWindowTitle(QCoreApplication.translate("DTSetting", u"DTSetting", None))
        self.label_font.setText(QCoreApplication.translate("DTSetting", u"Font (font-size is fixed)", None))
        self.label_contrast.setText(QCoreApplication.translate("DTSetting", u"Contrast", None))
        self.label_luminance.setText(QCoreApplication.translate("DTSetting", u"Luminance", None))
        self.pushButton_hue_reset.setText("")
        self.pushButton_luminance_reset.setText("")
        self.pushButton_saturation_reset.setText("")
        self.label_saturation.setText(QCoreApplication.translate("DTSetting", u"Saturation", None))
        self.label_hue.setText(QCoreApplication.translate("DTSetting", u"Hue", None))
        self.pushButton_contrast_reset.setText("")
        self.checkBox_reverse.setText(QCoreApplication.translate("DTSetting", u"Reverse", None))
        self.label_scale.setText(QCoreApplication.translate("DTSetting", u"Scale (Change this according to your screen DPI)", None))
        self.label_window_effect.setText(QCoreApplication.translate("DTSetting", u"Window Effect", None))
        self.label_language.setText(QCoreApplication.translate("DTSetting", u"Language", None))
        self.label_data_dir.setText(QCoreApplication.translate("DTSetting", u"Data Dir", None))
        self.comboBox_window_effect.setItemText(0, QCoreApplication.translate("DTSetting", u"Normal", None))
        self.comboBox_window_effect.setItemText(1, QCoreApplication.translate("DTSetting", u"Aero", None))
        self.comboBox_window_effect.setItemText(2, QCoreApplication.translate("DTSetting", u"Acrylic", None))

        self.label_backup.setText(QCoreApplication.translate("DTSetting", u"Backup Dst", None))
        self.label_password.setText(QCoreApplication.translate("DTSetting", u"Password", None))
        self.label_theme.setText(QCoreApplication.translate("DTSetting", u"Theme", None))
        self.label_country.setText(QCoreApplication.translate("DTSetting", u"Country", None))
        self.label_color_preview.setText("")
    # retranslateUi




from __future__ import annotations
from DTPySide import *

base=os.path.dirname(__file__)+"\\"

Language_Dict={
    "简体中文": (QLocale.Language.Chinese, base+"zh_CN.qm"),
    "繁體中文": (QLocale.Language.LiteraryChinese, base+"zh_TW.qm"),
    "English": (QLocale.Language.English, base+"en.qm"),
    "Русский": (QLocale.Language.Russian, base+"ru.qm"),
    "日本語": (QLocale.Language.Japanese, base+"ja.qm"),
    "Esperanto": (QLocale.Language.Esperanto, base+"eo.qm")
}

Country_Dict={
    "中国":QLocale.Country.China,
    "United Kingdom":QLocale.Country.UnitedKingdom,
    "United States":QLocale.Country.UnitedStates,
    "日本":QLocale.Country.Japan,
    "Россия":QLocale.Country.Russia,
    "World":QLocale.Country.World
}


# -*- coding: utf-8 -*-

################################################################################
## Form generated from reading UI file 'Ui_DTMessageBox.ui'
##
## Created by: Qt User Interface Compiler version 5.15.2
##
## WARNING! All changes made in this file will be lost when recompiling UI file!
################################################################################

from PySide2.QtCore import *
from PySide2.QtGui import *
from PySide2.QtWidgets import *

import DTPySide.DT_rc

class Ui_DTMessageBox(object):
    def setupUi(self, DTMessageBox):
        if not DTMessageBox.objectName():
            DTMessageBox.setObjectName(u"DTMessageBox")
        DTMessageBox.resize(528, 123)
        self.horizontalLayout = QHBoxLayout(DTMessageBox)
        self.horizontalLayout.setSpacing(10)
        self.horizontalLayout.setObjectName(u"horizontalLayout")
        self.horizontalLayout.setContentsMargins(0, 10, 0, 0)
        self.verticalLayout = QVBoxLayout()
        self.verticalLayout.setSpacing(0)
        self.verticalLayout.setObjectName(u"verticalLayout")
        self.label_icon = QLabel(DTMessageBox)
        self.label_icon.setObjectName(u"label_icon")
        sizePolicy = QSizePolicy(QSizePolicy.Fixed, QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_icon.sizePolicy().hasHeightForWidth())
        self.label_icon.setSizePolicy(sizePolicy)
        self.label_icon.setMinimumSize(QSize(64, 64))
        self.label_icon.setMaximumSize(QSize(64, 64))
        self.label_icon.setScaledContents(True)
        self.label_icon.setAlignment(Qt.AlignLeading|Qt.AlignLeft|Qt.AlignVCenter)

        self.verticalLayout.addWidget(self.label_icon)

        self.verticalSpacer = QSpacerItem(0, 20, QSizePolicy.Minimum, QSizePolicy.Expanding)

        self.verticalLayout.addItem(self.verticalSpacer)


        self.horizontalLayout.addLayout(self.verticalLayout)

        self.verticalLayout_2 = QVBoxLayout()
        self.verticalLayout_2.setSpacing(0)
        self.verticalLayout_2.setObjectName(u"verticalLayout_2")
        self.label_text = QLabel(DTMessageBox)
        self.label_text.setObjectName(u"label_text")
        sizePolicy1 = QSizePolicy(QSizePolicy.MinimumExpanding, QSizePolicy.Maximum)
        sizePolicy1.setHorizontalStretch(0)
        sizePolicy1.setVerticalStretch(0)
        sizePolicy1.setHeightForWidth(self.label_text.sizePolicy().hasHeightForWidth())
        self.label_text.setSizePolicy(sizePolicy1)
        self.label_text.setMinimumSize(QSize(0, 0))
        self.label_text.setTextFormat(Qt.AutoText)
        self.label_text.setScaledContents(False)
        self.label_text.setAlignment(Qt.AlignLeading|Qt.AlignLeft|Qt.AlignTop)
        self.label_text.setWordWrap(True)
        self.label_text.setMargin(0)
        self.label_text.setTextInteractionFlags(Qt.LinksAccessibleByMouse|Qt.TextSelectableByMouse)

        self.verticalLayout_2.addWidget(self.label_text)

        self.textBrowser = QTextBrowser(DTMessageBox)
        self.textBrowser.setObjectName(u"textBrowser")
        self.textBrowser.setMinimumSize(QSize(400, 50))

        self.verticalLayout_2.addWidget(self.textBrowser)


        self.horizontalLayout.addLayout(self.verticalLayout_2)


        self.retranslateUi(DTMessageBox)

        QMetaObject.connectSlotsByName(DTMessageBox)
    # setupUi

    def retranslateUi(self, DTMessageBox):
        DTMessageBox.setWindowTitle(QCoreApplication.translate("DTMessageBox", u"DTMessageBox", None))
        self.label_icon.setText("")
        self.label_text.setText("")
    # retranslateUi




# -*- coding: utf-8 -*-

################################################################################
## Form generated from reading UI file 'Ui_DemoSettingPage.ui'
##
## Created by: Qt User Interface Compiler version 5.15.2
##
## WARNING! All changes made in this file will be lost when recompiling UI file!
################################################################################

from PySide2.QtCore import *
from PySide2.QtGui import *
from PySide2.QtWidgets import *


class Ui_DemoSettingPage(object):
    def setupUi(self, DemoSettingPage):
        if not DemoSettingPage.objectName():
            DemoSettingPage.setObjectName(u"DemoSettingPage")
        DemoSettingPage.resize(483, 369)
        self.page_1 = QWidget()
        self.page_1.setObjectName(u"page_1")
        self.horizontalLayout = QHBoxLayout(self.page_1)
        self.horizontalLayout.setObjectName(u"horizontalLayout")
        self.horizontalLayout.setContentsMargins(0, 0, 0, 0)
        self.scrollArea = QScrollArea(self.page_1)
        self.scrollArea.setObjectName(u"scrollArea")
        self.scrollArea.setFrameShape(QFrame.NoFrame)
        self.scrollArea.setVerticalScrollBarPolicy(Qt.ScrollBarAsNeeded)
        self.scrollArea.setHorizontalScrollBarPolicy(Qt.ScrollBarAlwaysOff)
        self.scrollArea.setWidgetResizable(True)
        self.scrollAreaWidgetContents = QWidget()
        self.scrollAreaWidgetContents.setObjectName(u"scrollAreaWidgetContents")
        self.scrollAreaWidgetContents.setGeometry(QRect(0, 0, 483, 369))
        self.gridLayout = QGridLayout(self.scrollAreaWidgetContents)
        self.gridLayout.setObjectName(u"gridLayout")
        self.gridLayout.setContentsMargins(0, 0, 15, 0)
        self.lineEdit_homelabel = QLineEdit(self.scrollAreaWidgetContents)
        self.lineEdit_homelabel.setObjectName(u"lineEdit_homelabel")

        self.gridLayout.addWidget(self.lineEdit_homelabel, 1, 0, 1, 1)

        self.verticalSpacer = QSpacerItem(20, 40, QSizePolicy.Minimum, QSizePolicy.Expanding)

        self.gridLayout.addItem(self.verticalSpacer, 2, 0, 1, 1)

        self.label_homelabel = QLabel(self.scrollAreaWidgetContents)
        self.label_homelabel.setObjectName(u"label_homelabel")

        self.gridLayout.addWidget(self.label_homelabel, 0, 0, 1, 1)

        self.scrollArea.setWidget(self.scrollAreaWidgetContents)

        self.horizontalLayout.addWidget(self.scrollArea)

        DemoSettingPage.addWidget(self.page_1)
        self.page_2 = QWidget()
        self.page_2.setObjectName(u"page_2")
        self.horizontalLayout_2 = QHBoxLayout(self.page_2)
        self.horizontalLayout_2.setObjectName(u"horizontalLayout_2")
        self.horizontalLayout_2.setContentsMargins(0, 0, 0, 0)
        self.label = QLabel(self.page_2)
        self.label.setObjectName(u"label")
        self.label.setAlignment(Qt.AlignCenter)

        self.horizontalLayout_2.addWidget(self.label)

        DemoSettingPage.addWidget(self.page_2)

        self.retranslateUi(DemoSettingPage)

        QMetaObject.connectSlotsByName(DemoSettingPage)
    # setupUi

    def retranslateUi(self, DemoSettingPage):
        DemoSettingPage.setWindowTitle(QCoreApplication.translate("DemoSettingPage", u"DemoSettingPage", None))
        self.label_homelabel.setText(QCoreApplication.translate("DemoSettingPage", u"Home Label", None))
        self.label.setText(QCoreApplication.translate("DemoSettingPage", u"This is Custome Setting Page2.", None))
    # retranslateUi




from __future__ import annotations
from DTPySide import *

class DTTree(QTreeWidget):
	def __init__(self, parent):
		super().__init__(parent=parent)
		self.setSortingEnabled(True)
		self.setEditTriggers(QAbstractItemView.NoEditTriggers)
		self.setAnimated(True)

		self.setExpandsOnDoubleClick(False)

		self.horizontalScrollBar().setVisible(False)
		
		self.header().setStretchLastSection(True)
		self.header().setDefaultSectionSize(80)
		self.header().setMinimumSectionSize(80)

		self.setSelectionMode(QAbstractItemView.ExtendedSelection)
		self.setSelectionBehavior(QAbstractItemView.SelectRows)

		self.setDragEnabled(True)
		self.setDragDropMode(QAbstractItemView.DragDrop)

		self.header().setDefaultAlignment(Qt.AlignCenter)
		self.setIndentation(20)
		
		self.ExpandDict={}
		self.ExpandCheckingColumn=-1 #不设置的话，就是全部expand
	
	def setColumn(self,column_list:list):
		self.setColumnCount(len(column_list))
		self.setHeaderLabels(column_list)
	
	def setExpandCheckingColumn(self,column:int):
		self.ExpandCheckingColumn=column

	def StoreTreeStatus(self):

		def ExpandCheck(root:QTreeWidgetItem):
			
			if self.ExpandDict.get(root.text(self.ExpandCheckingColumn))==None:
				self.ExpandDict[root.text(self.ExpandCheckingColumn)]=root.isExpanded()
			
			for index in range(root.childCount()):
				child=root.child(index)
				ExpandCheck(child)
		
		if self.ExpandCheckingColumn!=-1:
			self.ExpandDict={}
			ExpandCheck(self.invisibleRootItem())
		
		self.sort_index=self.header().sortIndicatorSection()
		self.sort_order=self.header().sortIndicatorOrder()
		self.header().setSortIndicator(-1,Qt.SortOrder.AscendingOrder) #因为如果有排序的话，再insertItem会有疏漏，所以提前取消排序

	def RestoreTreeStatus(self):
		def ExpandRestore(root:QTreeWidgetItem):
			try:
				root.setExpanded(self.ExpandDict[root.text(self.ExpandCheckingColumn)])
			except:
				pass
			for index in range(root.childCount()):
				child=root.child(index)
				ExpandRestore(child)
		
		def ExpandAll(root:QTreeWidgetItem):
			root.setExpanded(True)
			for index in range(root.childCount()):
				child=root.child(index)
				ExpandAll(child)
		
		if self.ExpandCheckingColumn!=-1:
			ExpandRestore(self.invisibleRootItem())
		else:
			ExpandAll(self.invisibleRootItem())
		
		self.header().setSortIndicator(self.sort_index,self.sort_order) # insertItem完了后，再把sort_index,sort_order设置回来


# -*- coding: utf-8 -*-

################################################################################
## Form generated from reading UI file 'Ui_DemoCentralWidget1.ui'
##
## Created by: Qt User Interface Compiler version 5.15.2
##
## WARNING! All changes made in this file will be lost when recompiling UI file!
################################################################################

from PySide2.QtCore import *
from PySide2.QtGui import *
from PySide2.QtWidgets import *

import DTPySide.DT_rc

class Ui_DemoCentralWidget1(object):
    def setupUi(self, DemoCentralWidget1):
        if not DemoCentralWidget1.objectName():
            DemoCentralWidget1.setObjectName(u"DemoCentralWidget1")
        DemoCentralWidget1.resize(400, 300)
        self.actionHello_World = QAction(DemoCentralWidget1)
        self.actionHello_World.setObjectName(u"actionHello_World")
        icon = QIcon()
        icon.addFile(u":/icons/icon/holoicon1.ico", QSize(), QIcon.Normal, QIcon.Off)
        self.actionHello_World.setIcon(icon)
        self.horizontalLayout = QHBoxLayout(DemoCentralWidget1)
        self.horizontalLayout.setObjectName(u"horizontalLayout")
        self.homelabel = QLabel(DemoCentralWidget1)
        self.homelabel.setObjectName(u"homelabel")
        font = QFont()
        font.setPointSize(24)
        self.homelabel.setFont(font)
        self.homelabel.setAlignment(Qt.AlignCenter)

        self.horizontalLayout.addWidget(self.homelabel)


        self.retranslateUi(DemoCentralWidget1)

        QMetaObject.connectSlotsByName(DemoCentralWidget1)
    # setupUi

    def retranslateUi(self, DemoCentralWidget1):
        DemoCentralWidget1.setWindowTitle(QCoreApplication.translate("DemoCentralWidget1", u"DemoCentralWidget1", None))
        self.actionHello_World.setText(QCoreApplication.translate("DemoCentralWidget1", u"Hello World", None))
        self.homelabel.setText("")
    # retranslateUi




from DTPySide import *

def Information():
	return IconFromCurrentTheme("info.svg")

def Question():
	return IconFromCurrentTheme("help-circle.svg")

def Warning():
	return IconFromCurrentTheme("alert-triangle.svg")

def Error():
	return IconFromCurrentTheme("x-circle.svg")

def Happy():
	return IconFromCurrentTheme("smile.svg")

def Unhappy():
	return IconFromCurrentTheme("frown.svg")

def Heart():
	return IconFromCurrentTheme("heart.svg")

def HoloIcon1():
	return QIcon(":/icons/icon/holoicon1.ico")

def HoloIcon2():
	return QIcon(":/icons/icon/holoicon2.ico")

def Lock():
	return IconFromCurrentTheme("lock.svg")

def Unlock():
	return IconFromCurrentTheme("unlock.svg")

def Holo01():
	return QIcon(":/icons/icon/holo01.ico")


from DTPySide.demo.demoModule.DemoSettingPage import DemoSettingPage
from DTPySide.demo.demoModule.DemoCentralWidget1 import DemoCentralWidget1
from DTPySide.demo.demoModule.DemoCentralWidget2 import DemoCentralWidget2
from DTPySide.demo.demoModule.widgetgallery import WidgetGallery


from __future__ import annotations
from DTPySide import *

# Dialog
from DTPySide.DTFrame.Ui_DTDialog import Ui_DTDialog
class DTDialog(Ui_DTDialog,QDialog):
	def __init__(self, parent, title):
		
		if parent==None:
			# Login
			super().__init__()
		else:
			super().__init__(parent)

		self.setupUi(self)

		self.TitleBar.btn_close.clicked.connect(self.close)
		
		# 现在有全局stylesheet和AA_UseStyleSheetPropagationInWidgetStyles了，就不用一个个写继承字体了
		# Makes a toplevel window inherit font, palette and locale from its parent.
		# self.setAttribute(Qt.WA_WindowPropagation,True)
		# 无边框
		self.setWindowFlags(Qt.Window | Qt.FramelessWindowHint)
		# 缩放角
		self.setSizeGripEnabled(True)
		
		self.TitleBar.setWindowTitle(title)
		self.TitleBar.setFull(False)
		self.TitleBar.updateWindowIcon()

		# 默认cancel
		# self.setDefaultButton(QDialogButtonBox.Cancel)
		self.setDefaultButton(QDialogButtonBox.Ok)
		
		self.adjustSize()
		MoveToCenterOfScreen(self)

	def setCentralWidget(self, widget):
		self.centralWidget.addWidget(widget)
	
	def setButtonBox(self,btns:QDialogButtonBox.StandardButton):
		self.buttonBox.setStandardButtons(btns)

	def setDefaultButton(self,btn:QDialogButtonBox.StandardButton):
		self.buttonBox.button(btn).setDefault(True)


from __future__ import annotations
from DTPySide import *

class DTCapsuleButton(QLabel):
	clicked=Signal()
	def __init__(self,parent,text,color):
		super().__init__(parent)
		self.setSizePolicy(QSizePolicy.Maximum,QSizePolicy.Fixed)
		
		self.setText(text)
		self.adjustSize()
		
		self.setStyleSheet(""" 
			QLabel {
				color: white;
				background-color: %s;
				border: 1px solid %s;
				border-radius: 12px;
			}
		"""%(color,color))

		# SET DROP SHADOW
		shadow = QGraphicsDropShadowEffect(self)
		shadow.setBlurRadius(0.8)
		shadow.setXOffset(4)
		shadow.setYOffset(4)
		shadow.setColor(QColor("#252525"))
		self.setGraphicsEffect(shadow)
	
	def mouseReleaseEvent(self,event):
		super().mouseReleaseEvent(event)
		if event.button()==Qt.LeftButton:
			self.clicked.emit()
	
	# Clear_Layout时调用deleteLater删除DTCapsuleButton，但shadow消不干净，那就setGraphicsEffect为空
	def deleteLater(self):
		super().deleteLater()
		self.setGraphicsEffect(None)



from DTPySide import *

from DTPySide.demo.demoModule import DemoSettingPage
class DemoSettingSession(DTSession.DTSettingSession):
	def __init__(self, Headquarter, app):
		super().__init__(Headquarter ,app)
		self.SettingPages=DemoSettingPage(Headquarter)
		
		MenuButton1=DTWidget.DTSettingButton(IconFromCurrentTheme("at-sign.svg"))
		self.addButtonAndPage(MenuButton1,self.SettingPages.page_1)
		
		MenuButton2=DTWidget.DTSettingButton(IconFromCurrentTheme("anchor.svg"))
		self.addButtonAndPage(MenuButton2,self.SettingPages.page_2)


from __future__ import annotations
from DTPySide import *


from ctypes import POINTER, Structure, c_bool, c_int, pointer, sizeof, WinDLL, byref, cast
from ctypes.wintypes import DWORD, HWND, ULONG, POINT, RECT, UINT , LONG, LPCVOID, MSG
from enum import Enum


class WINDOWCOMPOSITIONATTRIB(Enum):
	WCA_UNDEFINED = 0,
	WCA_NCRENDERING_ENABLED = 1,
	WCA_NCRENDERING_POLICY = 2,
	WCA_TRANSITIONS_FORCEDISABLED = 3,
	WCA_ALLOW_NCPAINT = 4,
	WCA_CAPTION_BUTTON_BOUNDS = 5,
	WCA_NONCLIENT_RTL_LAYOUT = 6,
	WCA_FORCE_ICONIC_REPRESENTATION = 7,
	WCA_EXTENDED_FRAME_BOUNDS = 8,
	WCA_HAS_ICONIC_BITMAP = 9,
	WCA_THEME_ATTRIBUTES = 10,
	WCA_NCRENDERING_EXILED = 11,
	WCA_NCADORNMENTINFO = 12,
	WCA_EXCLUDED_FROM_LIVEPREVIEW = 13,
	WCA_VIDEO_OVERLAY_ACTIVE = 14,
	WCA_FORCE_ACTIVEWINDOW_APPEARANCE = 15,
	WCA_DISALLOW_PEEK = 16,
	WCA_CLOAK = 17,
	WCA_CLOAKED = 18,
	WCA_ACCENT_POLICY = 19,
	WCA_FREEZE_REPRESENTATION = 20,
	WCA_EVER_UNCLOAKED = 21,
	WCA_VISUAL_OWNER = 22,
	WCA_LAST = 23


class ACCENT_STATE(Enum):
	""" 客户区状态枚举类 """
	ACCENT_DISABLED = 0,
	ACCENT_ENABLE_GRADIENT = 1,
	ACCENT_ENABLE_TRANSPARENTGRADIENT = 2,
	ACCENT_ENABLE_BLURBEHIND = 3,          # Aero效果
	ACCENT_ENABLE_ACRYLICBLURBEHIND = 4,   # 亚克力效果
	ACCENT_INVALID_STATE = 5


class ACCENT_POLICY(Structure):
	""" 设置客户区的具体属性 """

	_fields_ = [
		("AccentState",     DWORD),
		("AccentFlags",     DWORD),
		("GradientColor",   DWORD),
		("AnimationId",     DWORD),
	]


class WINDOWCOMPOSITIONATTRIBDATA(Structure):
	_fields_ = [
		("Attribute",   DWORD),
		# POINTER()接收任何ctypes类型，并返回一个指针类型
		("Data",        POINTER(ACCENT_POLICY)),
		("SizeOfData",  ULONG),
	]


class DWMNCRENDERINGPOLICY(Enum):
	DWMNCRP_USEWINDOWSTYLE = 0
	DWMNCRP_DISABLED = 1
	DWMNCRP_ENABLED = 2
	DWMNCRP_LAS = 3


class DWMWINDOWATTRIBUTE(Enum):
	DWMWA_NCRENDERING_ENABLED = 1
	DWMWA_NCRENDERING_POLICY = 2
	DWMWA_TRANSITIONS_FORCEDISABLED = 3
	DWMWA_ALLOW_NCPAINT = 4
	DWMWA_CAPTION_BUTTON_BOUNDS = 5
	DWMWA_NONCLIENT_RTL_LAYOUT = 6
	DWMWA_FORCE_ICONIC_REPRESENTATION = 7
	DWMWA_FLIP3D_POLICY = 8
	DWMWA_EXTENDED_FRAME_BOUNDS = 9
	DWMWA_HAS_ICONIC_BITMAP = 10
	DWMWA_DISALLOW_PEEK = 11
	DWMWA_EXCLUDED_FROM_PEEK = 12
	DWMWA_CLOAK = 13
	DWMWA_CLOAKED = 14
	DWMWA_FREEZE_REPRESENTATION = 25
	DWMWA_LAST = 16


class MARGINS(Structure):
	_fields_ = [
		("cxLeftWidth",     c_int),
		("cxRightWidth",    c_int),
		("cyTopHeight",     c_int),
		("cyBottomHeight",  c_int),
	]


class MINMAXINFO(Structure):
	_fields_ = [
		("ptReserved",      POINT),
		("ptMaxSize",       POINT),
		("ptMaxPosition",   POINT),
		("ptMinTrackSize",  POINT),
		("ptMaxTrackSize",  POINT),
	]


class PWINDOWPOS(Structure):
	_fields_ = [
		('hWnd',            HWND),
		('hwndInsertAfter', HWND),
		('x',               c_int),
		('y',               c_int),
		('cx',              c_int),
		('cy',              c_int),
		('flags',           UINT)
	]


class NCCALCSIZE_PARAMS(Structure):
	_fields_ = [
		('rgrc', RECT*3),
		('lppos', POINTER(PWINDOWPOS))
	]


class WindowEffect:
	""" 调用windows api实现窗口效果 """

	def __init__(self):
		# 调用api
		self.user32 = WinDLL("user32")
		self.dwmapi = WinDLL("dwmapi")
		self.SetWindowCompositionAttribute = self.user32.SetWindowCompositionAttribute
		self.DwmExtendFrameIntoClientArea = self.dwmapi.DwmExtendFrameIntoClientArea
		self.DwmSetWindowAttribute = self.dwmapi.DwmSetWindowAttribute
		self.SetWindowCompositionAttribute.restype = c_bool
		self.DwmExtendFrameIntoClientArea.restype = LONG
		self.DwmSetWindowAttribute.restype = LONG
		self.SetWindowCompositionAttribute.argtypes = [
			c_int,
			POINTER(WINDOWCOMPOSITIONATTRIBDATA),
		]
		self.DwmSetWindowAttribute.argtypes = [c_int, DWORD, LPCVOID, DWORD]
		self.DwmExtendFrameIntoClientArea.argtypes = [c_int, POINTER(MARGINS)]
		# 初始化结构体
		self.accentPolicy = ACCENT_POLICY()
		self.winCompAttrData = WINDOWCOMPOSITIONATTRIBDATA()
		self.winCompAttrData.Attribute = WINDOWCOMPOSITIONATTRIB.WCA_ACCENT_POLICY.value[
			0
		]
		self.winCompAttrData.SizeOfData = sizeof(self.accentPolicy)
		self.winCompAttrData.Data = pointer(self.accentPolicy)

	def setAcrylicEffect(self, hWnd, gradientColor: str = "52557018", isEnableShadow: bool = True, animationId: int = 0):
		""" 给窗口开启Win10的亚克力效果34374620 52557018

		Parameter
		----------
		hWnd: int or `sip.voidptr`
			窗口句柄

		gradientColor: str
			十六进制亚克力混合色，对应rgba四个分量

		isEnableShadow: bool
			控制是否启用窗口阴影

		animationId: int
			控制磨砂动画
		
		拖动缓慢：去掉高级系统设置 -> 性能 -> 拖动时显示窗口内容 复选框的 √
		"""

		# 亚克力混合色
		gradientColor = (
			gradientColor[6:]
			+ gradientColor[4:6]
			+ gradientColor[2:4]
			+ gradientColor[:2]
		)
		gradientColor = DWORD(int(gradientColor, base=16))
		# 磨砂动画
		animationId = DWORD(animationId)
		# 窗口阴影
		accentFlags = DWORD(0x20 | 0x40 | 0x80 |
							0x100) if isEnableShadow else DWORD(0)
		self.accentPolicy.AccentState = ACCENT_STATE.ACCENT_ENABLE_ACRYLICBLURBEHIND.value[
			0
		]
		self.accentPolicy.GradientColor = gradientColor
		self.accentPolicy.AccentFlags = accentFlags
		self.accentPolicy.AnimationId = animationId
		# 开启亚克力
		self.SetWindowCompositionAttribute(hWnd, pointer(self.winCompAttrData))

	def setAeroEffect(self, hWnd):
		""" 给窗口开启Aero效果

		Parameter
		----------
		hWnd: int or `sip.voidptr`
			窗口句柄
		"""
		self.accentPolicy.AccentState = ACCENT_STATE.ACCENT_ENABLE_BLURBEHIND.value[0]
		# 开启Aero
		self.SetWindowCompositionAttribute(hWnd, pointer(self.winCompAttrData))

	def moveWindow(self, hWnd):
		""" 移动窗口

		Parameter
		----------
		hWnd: int or `sip.voidptr`
			窗口句柄
		"""
		win32gui.ReleaseCapture()
		win32api.SendMessage(
			hWnd, win32con.WM_SYSCOMMAND, win32con.SC_MOVE + win32con.HTCAPTION, 0
		)

	def addShadowEffect(self, hWnd):
		""" 给窗口添加阴影

		Parameter
		----------
		hWnd: int or `sip.voidptr`
			窗口句柄
		"""
		hWnd = int(hWnd)
		self.DwmSetWindowAttribute(
			hWnd,
			DWMWINDOWATTRIBUTE.DWMWA_NCRENDERING_POLICY.value,
			byref(c_int(DWMNCRENDERINGPOLICY.DWMNCRP_ENABLED.value)),
			4,
		)
		margins = MARGINS(-1, -1, -1, -1)
		self.DwmExtendFrameIntoClientArea(hWnd, byref(margins))

	def addWindowAnimation(self, hWnd):
		""" 打开窗口动画效果

		Parameters
		----------
		hWnd : int or `sip.voidptr`
			窗口句柄
		"""
		style = win32gui.GetWindowLong(hWnd, win32con.GWL_STYLE)
		win32gui.SetWindowLong(
			hWnd,
			win32con.GWL_STYLE,
			style
			# | win32con.WS_MAXIMIZEBOX
			# | win32con.WS_CAPTION
			# | win32con.CS_DBLCLKS
			# | win32con.WS_THICKFRAME,
			| win32con.WS_OVERLAPPEDWINDOW,
		)

		# 奶奶的不写WS_MAXIMIZEBOX、WS_CAPTION的话，拖动到顶端的最大化将会出现空隙
		# 但写了的话用Aero全透明就会出现windows自带的三个窗口title按钮，咋办呢？
		# 只能用亚克力Acrylic，或者用Aero的时候把Title设置为不透明好了……
		# 花了半个多小时的时间……

class DTWindow(QWidget):
	BORDER_WIDTH = 5

	def closeEvent(self, event):
		super().closeEvent(event)
	
	def show(self):
		if self.isMaximized():
			# 如果关掉的时候是最大化的话，再进行恢复show，就会有bug
			self.showNormal()
			self.showMaximized()
		else:
			ShowUp(self)

	def __init__(self, app:DTAPP, parent=None):
		super().__init__(parent=parent)
		self.app=app
		
		self.__monitor_info = None

		self.setWindowFlags(Qt.Window | Qt.FramelessWindowHint | Qt.WindowSystemMenuHint | Qt.WindowMinimizeButtonHint | Qt.WindowMaximizeButtonHint)
		self.initializeWindowEffect()
	
	def reInitialize(self):
		self.__monitor_info = None

		self.setWindowFlags(Qt.Window | Qt.FramelessWindowHint | Qt.WindowSystemMenuHint | Qt.WindowMinimizeButtonHint | Qt.WindowMaximizeButtonHint)
		self.initializeWindowEffect()
	
	def initializeWindowEffect(self):
		"""设置窗口效果，Normal 或 Aero 或 Acrylic
		"""

		self.windowEffect = WindowEffect()
		self.windowEffect.addWindowAnimation(self.winId())
		
		window_effect=self.app.WindowEffect()

		if window_effect=="Normal":
			# Normal
			self.windowEffect.addShadowEffect(self.winId())
		
		elif window_effect=="Aero":
			# Aero
			self.windowEffect.setAeroEffect(self.winId())
			self.windowEffect.addShadowEffect(self.winId())
			
		elif window_effect=="Acrylic":
			# Acrylic
			self.windowEffect.setAcrylicEffect(self.winId())
	
	
	def isWindowMaximized(self, hWnd) -> bool:
		""" 判断窗口是否最大化 """
		# 返回指定窗口的显示状态以及被恢复的、最大化的和最小化的窗口位置，返回值为元组
		windowPlacement = win32gui.GetWindowPlacement(hWnd)
		if not windowPlacement:
			return False
		return windowPlacement[1] == win32con.SW_MAXIMIZE

	def nativeEvent(self, eventType, message):
		""" 处理windows消息 """
		try:
			scale=self.app.Scale()
			msg = MSG.from_address(message.__int__())
			if msg.message == win32con.WM_NCHITTEST and not self.isWindowMaximized(msg.hWnd):
				# 鼠标在窗口中移动

				# 解决多屏下会出现鼠标一直为拖动状态的问题
				
				xPos = (win32api.LOWORD(msg.lParam) -
						self.frameGeometry().x()*scale) % 65536
				yPos = win32api.HIWORD(msg.lParam) - self.frameGeometry().y()*scale
				w, h = self.width()*scale, self.height()*scale
				
				lx = xPos -4 < self.BORDER_WIDTH
				rx = xPos +4 > w - self.BORDER_WIDTH
				ty = yPos -4 < self.BORDER_WIDTH
				by = yPos +4 > h - self.BORDER_WIDTH
				
				if lx and ty:
					return True, win32con.HTTOPLEFT
				elif rx and by:
					return True, win32con.HTBOTTOMRIGHT
				elif rx and ty:
					return True, win32con.HTTOPRIGHT
				elif lx and by:
					return True, win32con.HTBOTTOMLEFT
				elif ty:
					return True, win32con.HTTOP
				elif by:
					return True, win32con.HTBOTTOM
				elif lx:
					return True, win32con.HTLEFT
				elif rx:
					return True, win32con.HTRIGHT
				
			
			elif msg.message == win32con.WM_NCCALCSIZE:
				# 窗口缩放大小
				if self.isWindowMaximized(msg.hWnd):
					self.monitorNCCALCSIZE(msg)
					
					#变成最大化
					try:
						self.TitleBar.btn_maximize.setIcon(self.TitleBar.restore_icon)
					except:
						pass
				else:
					
					#变成正常
					try:
						self.TitleBar.btn_maximize.setIcon(self.TitleBar.maximize_icon)
					except:
						pass
				return True, 0
			
			elif msg.message == win32con.WM_GETMINMAXINFO:
				# 窗口移动
				if self.isWindowMaximized(msg.hWnd):
					window_rect = win32gui.GetWindowRect(msg.hWnd)
					if not window_rect:
						return False, 0
					# 获取显示器句柄
					monitor = win32api.MonitorFromRect(window_rect)
					if not monitor:
						return False, 0
					# 获取显示器信息
					monitor_info = win32api.GetMonitorInfo(monitor)
					monitor_rect = monitor_info['Monitor']
					work_area = monitor_info['Work']
					# 将lParam转换为MINMAXINFO指针
					info = cast(msg.lParam, POINTER(MINMAXINFO)).contents
					# 调整窗口大小
					info.ptMaxSize.x = work_area[2] - work_area[0]
					info.ptMaxSize.y = work_area[3] - work_area[1]
					info.ptMaxTrackSize.x = info.ptMaxSize.x
					info.ptMaxTrackSize.y = info.ptMaxSize.y
					# 修改左上角坐标
					info.ptMaxPosition.x = abs(window_rect[0] - monitor_rect[0])
					info.ptMaxPosition.y = abs(window_rect[1] - monitor_rect[1])
					return True, 1
			
			return QWidget.nativeEvent(self, eventType, message)

		except:
			pass

	def monitorNCCALCSIZE(self, msg: MSG):
		"""放大到全屏"""

		monitor = win32api.MonitorFromWindow(msg.hWnd)
		# 如果没有保存显示器信息就直接返回，否则接着调整窗口大小
		if monitor is None and not self.__monitor_info:
			return
		elif monitor is not None:
			self.__monitor_info = win32api.GetMonitorInfo(monitor)
		# 调整窗口大小
		params = cast(msg.lParam, POINTER(NCCALCSIZE_PARAMS)).contents
		params.rgrc[0].left = self.__monitor_info['Work'][0]
		params.rgrc[0].top = self.__monitor_info['Work'][1]
		params.rgrc[0].right = self.__monitor_info['Work'][2]
		params.rgrc[0].bottom = self.__monitor_info['Work'][3]


from __future__ import annotations
from DTPySide import *

class DTToolTip(QLabel):
	def __init__(self, parent, tooltip):
		super().__init__(tooltip,parent)
		
		self.setStyleSheet(""" 
			QLabel {
				background-color: #0C0B0B;	
				color: #E6E6E6;
				padding-left: 10px;
				padding-right: 10px;
				border: 1px solid #0C0B0B;
				border-radius: 12px;
				border-left: 3px solid #FF6265;
			}
		""")
		
		self.adjustSize()

		# SET OPACITY
		opacity = QGraphicsOpacityEffect(self)
		opacity.setOpacity(0.85)
		self.setGraphicsEffect(opacity)



from DTPySide import *

from DTPySide.demo.demoModule.Ui_DemoCentralWidget1 import Ui_DemoCentralWidget1
class DemoCentralWidget1(Ui_DemoCentralWidget1,QWidget):
    def __init__(self,Headquarter):
        super().__init__(Headquarter)
        self.setupUi(self)
        
        try:
            self.homelabel.setText("HomeLabel's Text is: "+Headquarter.UserSetting().value("HomePage/HomeLabel"))
        except:
            pass
        
        # implement custom stylesheet
        self.homelabel.setStyleSheet('background:red')
        self.actionHello_World.triggered.connect(lambda:DTFrame.DTMessageBox(Headquarter,"Hello World","Hello! Welcome to Dongli Teahouse PySide.",DTIcon.Holo01()))


from __future__ import annotations
from DTPySide import *

from DTPySide.DTWidget.Ui_DTTitleBar import Ui_DTTitleBar
class DTTitleBar(Ui_DTTitleBar,QWidget):
	def __init__(self,parent):
		super().__init__(parent)
		self.setupUi(self)
		self.full=True

		self.maximize_icon=IconFromCurrentTheme("window-maximize.svg")
		self.restore_icon=IconFromCurrentTheme("window-restore.svg")
		
		if self.window().isMaximized():
			#是最大化的
			self.btn_maximize.setIcon(self.restore_icon)
		else:
			self.btn_maximize.setIcon(self.maximize_icon)

		self.title_icon.setIcon(QIcon(":/icons/icon/holoicon1.ico"))
		self.btn_minimize.setIcon(IconFromCurrentTheme("window-minimize.svg"))
		self.btn_close.setIcon(IconFromCurrentTheme("x.svg"))
		
	
	def setFull(self,full:bool):
		
		self.full=full
		
		if self.full==False:
			self.btn_maximize.hide()
			self.btn_minimize.hide()
		if self.full==True:
			self.btn_maximize.clicked.connect(lambda:self.mouseDoubleClickEvent(None,True))
			self.btn_minimize.clicked.connect(self.window().showMinimized)
			self.title_icon.clicked.connect(lambda:show_ContextMenu_Beneath(self.window().MainMenu(),self.title_icon))

	def setWindowTitle(self,title):
		super().setWindowTitle(title)
		self.label_titlebar.setText(title)
	
	def updateWindowIcon(self):
		# windowIcon是自动继承的，直接设置就好了
		self.title_icon.setIcon(self.windowIcon())

	def mouseDoubleClickEvent(self, event, ignore_event=False):
		"""最大化最小化切换

		Args:
			event ([type]): [description]
			ignore_event (bool, optional): 没有event的话，想调用这个函数，event设为None，ignore_event设为True就行了. Defaults to False.
		"""		

		if self.full==True:
			if ignore_event==False and event.button() != Qt.LeftButton:
				return
			
			if self.btn_maximize.isHidden():
				self.btn_maximize.show()
			if self.btn_minimize.isHidden():
				self.btn_minimize.show()
			
			if self.window().isMaximized() or self.window().isFullScreen():

				#变成正常
				self.window().showNormal()
				self.btn_maximize.setIcon(self.maximize_icon)

			else:

				#变成最大化
				self.window().showMaximized()
				self.btn_maximize.setIcon(self.restore_icon)

	def mousePressEvent(self, event):
		""" 移动窗口 """
		if not self.window().isFullScreen():
			win32gui.ReleaseCapture()
			win32gui.SendMessage(self.window().winId(), win32con.WM_SYSCOMMAND,
						win32con.SC_MOVE + win32con.HTCAPTION, 0)
			event.ignore()


from DTPySide import *

from DTPySide.demo.demoModule import DemoCentralWidget2
class DemoMainSession2(DTFrame.DTMainWindow):
    def __init__(self,Headquarter):
        super().__init__(Headquarter.app)
        self.CentralWidget=DemoCentralWidget2(Headquarter)
        self.setCentralWidget(self.CentralWidget)
        MoveToCenterOfScreen(self)
        self.setWindowTitle("Demo Window 2")


from DTPySide.DTWidget.DTCapsuleButton import DTCapsuleButton
from DTPySide.DTWidget.DTApplyButton import DTApplyButton
from DTPySide.DTWidget.DTSettingButton import DTSettingButton
from DTPySide.DTWidget.DTTitleBar import DTTitleBar
from DTPySide.DTWidget.DTToolTip import DTToolTip
from DTPySide.DTWidget.DTWindow import DTWindow
from DTPySide.DTWidget.DTPlainTextEdit import DTPlainTextEdit
from DTPySide.DTWidget.DTHorizontalTabel import DTHorizontalTabel
from DTPySide.DTWidget.DTTree import DTTree
from DTPySide.DTWidget.LazyCombobox import LazyCombobox
from DTPySide.DTWidget.MarkdownViewer import MarkdownViewer
from DTPySide.DTWidget.DTLine import DTLine


from DTPySide.demo.demoSession.DemoMainSession import DemoMainSession
from DTPySide.demo.demoSession.DemoMainSession2 import DemoMainSession2
from DTPySide.demo.demoSession.DemoSettingSession import DemoSettingSession


from DTPySide import *

from DTPySide.demo.demoSession.DemoMainSession2 import DemoMainSession2
from DTPySide.demo.demoSession.DemoSettingSession import DemoSettingSession
from DTPySide.demo.demoModule import DemoCentralWidget1,WidgetGallery

class DemoMainSession(DTSession.DTMainSession):
	def __init__(self,app):
		super().__init__(app)

	def initializeWindow(self):
		super().initializeWindow()

		self.Widget=DemoCentralWidget1(self)
		self.CentralWidget=WidgetGallery(self)
		self.CentralWidget.main_layout.addWidget(self.Widget)

		self.setCentralWidget(self.CentralWidget)


	def initializeMenu(self):
		self.addActionToMainMenu(self.Widget.actionHello_World)
		
		self.actionSummonMainWindow2=QAction("MainWindow 2")
		self.actionSummonMainWindow2.setIcon(DTIcon.Happy())
		self.actionSummonMainWindow2.triggered.connect(self.summonMainWindow2)
		self.addActionToMainMenu(self.actionSummonMainWindow2)

		super().initializeMenu()

	def summonMainWindow2(self):
		self.MainWindow2=DemoMainSession2(self)
		self.MainWindow2.initialize()
		self.MainWindow2.show()

	def setting(self):
		dlg=DemoSettingSession(self, self.app)
		dlg.exec_()


from __future__ import annotations
from DTPySide import *

class LazyCombobox(QComboBox):
	def __init__(self, parent):
		super().__init__(parent)
		self.setFocusPolicy(Qt.StrongFocus)

	def wheelEvent(self, event):
		event.ignore()


# -*- coding: utf-8 -*-

################################################################################
## Form generated from reading UI file 'Ui_DTMainWindow.ui'
##
## Created by: Qt User Interface Compiler version 5.15.2
##
## WARNING! All changes made in this file will be lost when recompiling UI file!
################################################################################

from PySide2.QtCore import *
from PySide2.QtGui import *
from PySide2.QtWidgets import *

from DTPySide.DTWidget.DTTitleBar import DTTitleBar

import DTPySide.DT_rc

class Ui_DTMainWindow(object):
    def setupUi(self, DTMainWindow):
        if not DTMainWindow.objectName():
            DTMainWindow.setObjectName(u"DTMainWindow")
        DTMainWindow.resize(1278, 960)
        self.actionSetting = QAction(DTMainWindow)
        self.actionSetting.setObjectName(u"actionSetting")
        self.actionExit = QAction(DTMainWindow)
        self.actionExit.setObjectName(u"actionExit")
        self.actionMaximize_Window = QAction(DTMainWindow)
        self.actionMaximize_Window.setObjectName(u"actionMaximize_Window")
        self.actionNormalize_Window = QAction(DTMainWindow)
        self.actionNormalize_Window.setObjectName(u"actionNormalize_Window")
        self.actionMinimize_Window = QAction(DTMainWindow)
        self.actionMinimize_Window.setObjectName(u"actionMinimize_Window")
        self.actionWindow_Toggle_Stay_on_Top = QAction(DTMainWindow)
        self.actionWindow_Toggle_Stay_on_Top.setObjectName(u"actionWindow_Toggle_Stay_on_Top")
        self.actionWindow_Toggle_Fullscreen = QAction(DTMainWindow)
        self.actionWindow_Toggle_Fullscreen.setObjectName(u"actionWindow_Toggle_Fullscreen")
        self.actionAbout = QAction(DTMainWindow)
        self.actionAbout.setObjectName(u"actionAbout")
        self.actionBoss_Key = QAction(DTMainWindow)
        self.actionBoss_Key.setObjectName(u"actionBoss_Key")
        self.actionBackup = QAction(DTMainWindow)
        self.actionBackup.setObjectName(u"actionBackup")
        self.verticalLayout = QVBoxLayout(DTMainWindow)
        self.verticalLayout.setSpacing(0)
        self.verticalLayout.setObjectName(u"verticalLayout")
        self.verticalLayout.setContentsMargins(0, 0, 0, 0)
        self.TitleBar = DTTitleBar(DTMainWindow)
        self.TitleBar.setObjectName(u"TitleBar")

        self.verticalLayout.addWidget(self.TitleBar)

        self.centralWidget = QFrame(DTMainWindow)
        self.centralWidget.setObjectName(u"centralWidget")
        sizePolicy = QSizePolicy(QSizePolicy.Preferred, QSizePolicy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.centralWidget.sizePolicy().hasHeightForWidth())
        self.centralWidget.setSizePolicy(sizePolicy)
        self.centralwidget = QVBoxLayout(self.centralWidget)
        self.centralwidget.setSpacing(0)
        self.centralwidget.setObjectName(u"centralwidget")
        self.centralwidget.setContentsMargins(0, 0, 0, 0)

        self.verticalLayout.addWidget(self.centralWidget)

        self.statusBar = QLabel(DTMainWindow)
        self.statusBar.setObjectName(u"statusBar")
        sizePolicy1 = QSizePolicy(QSizePolicy.Preferred, QSizePolicy.Fixed)
        sizePolicy1.setHorizontalStretch(0)
        sizePolicy1.setVerticalStretch(0)
        sizePolicy1.setHeightForWidth(self.statusBar.sizePolicy().hasHeightForWidth())
        self.statusBar.setSizePolicy(sizePolicy1)
        self.statusBar.setMinimumSize(QSize(0, 20))
        self.statusBar.setMaximumSize(QSize(16777215, 20))

        self.verticalLayout.addWidget(self.statusBar)


        self.retranslateUi(DTMainWindow)

        QMetaObject.connectSlotsByName(DTMainWindow)
    # setupUi

    def retranslateUi(self, DTMainWindow):
        DTMainWindow.setWindowTitle(QCoreApplication.translate("DTMainWindow", u"DTMainWindow", None))
        self.actionSetting.setText(QCoreApplication.translate("DTMainWindow", u"Setting", None))
#if QT_CONFIG(tooltip)
        self.actionSetting.setToolTip(QCoreApplication.translate("DTMainWindow", u"Setting", None))
#endif // QT_CONFIG(tooltip)
        self.actionExit.setText(QCoreApplication.translate("DTMainWindow", u"Exit", None))
#if QT_CONFIG(shortcut)
        self.actionExit.setShortcut(QCoreApplication.translate("DTMainWindow", u"Ctrl+W", None))
#endif // QT_CONFIG(shortcut)
        self.actionMaximize_Window.setText(QCoreApplication.translate("DTMainWindow", u"Maximize Window", None))
        self.actionNormalize_Window.setText(QCoreApplication.translate("DTMainWindow", u"Normalize Window", None))
        self.actionMinimize_Window.setText(QCoreApplication.translate("DTMainWindow", u"Minimize Window", None))
        self.actionWindow_Toggle_Stay_on_Top.setText(QCoreApplication.translate("DTMainWindow", u"Window Toggle Stay on Top", None))
#if QT_CONFIG(shortcut)
        self.actionWindow_Toggle_Stay_on_Top.setShortcut(QCoreApplication.translate("DTMainWindow", u"F12", None))
#endif // QT_CONFIG(shortcut)
        self.actionWindow_Toggle_Fullscreen.setText(QCoreApplication.translate("DTMainWindow", u"Window Toggle Fullscreen", None))
#if QT_CONFIG(shortcut)
        self.actionWindow_Toggle_Fullscreen.setShortcut(QCoreApplication.translate("DTMainWindow", u"F11", None))
#endif // QT_CONFIG(shortcut)
        self.actionAbout.setText(QCoreApplication.translate("DTMainWindow", u"About", None))
        self.actionBoss_Key.setText(QCoreApplication.translate("DTMainWindow", u"Boss Key", None))
#if QT_CONFIG(shortcut)
        self.actionBoss_Key.setShortcut(QCoreApplication.translate("DTMainWindow", u"F1", None))
#endif // QT_CONFIG(shortcut)
        self.actionBackup.setText(QCoreApplication.translate("DTMainWindow", u"Backup", None))
    # retranslateUi




from DTPySide import *

from DTPySide.demo.demoModule.Ui_DemoSettingPage import Ui_DemoSettingPage
class DemoSettingPage(Ui_DemoSettingPage,QStackedWidget):
	def __init__(self,Headquarter):
		super().__init__(Headquarter)
		self.setupUi(self)

		self.Headquarter=Headquarter
		self.initializeWindow()
		self.initializeSignal()
	
	def initializeWindow(self):
		self.lineEdit_homelabel.setText(self.Headquarter.UserSetting().value("HomePage/HomeLabel"))
	
	def initializeSignal(self):
		self.lineEdit_homelabel.editingFinished.connect(self.setHomeLabel)
	
	def setHomeLabel(self):
		s=self.lineEdit_homelabel.text()
		self.Headquarter.Widget.homelabel.setText("HomeLabel's Text is: "+s)
		self.Headquarter.UserSetting().setValue("HomePage/HomeLabel",s)


import os

os.chdir(os.path.dirname(__file__))
for i in os.listdir("./"):
    name=os.path.splitext(i)[0]
    ext=os.path.splitext(i)[1]
    if ext==".ts":
        os.system("lrelease %s -qm %s.qm"%(i,name))


import os
import shutil


def deepin(base):
	
	base=os.path.abspath(base)
	os.chdir(base)

	for i in os.listdir("./"):
		if os.path.isdir(i):
			if i=="__pycache__":
				shutil.rmtree(os.path.abspath(i))
				continue
			deepin(i)
			os.chdir(base)
		else:
			name=os.path.splitext(i)[0]
			ext=os.path.splitext(i)[1]
			if ext==".ui":
				os.system("pyside2-uic %s.ui -o %s.py"%(name,name))
				with open("%s.py"%name,"r+",encoding="utf-8") as f:
					s=f.read()
					s=s.replace("import DT_rc","import DTPySide.DT_rc")
					s=s.replace("from DT","from DTPySide.DT")
					f.seek(0)
					f.write(s)

base=os.getcwd()
deepin(base)


from __future__ import annotations
from DTPySide import *

class DTSettingButton(QPushButton):
	def __init__(self,icon):
		super().__init__()
		self.setIcon(icon)
		self.setFlat(True)
		self.setStyleSheet("""
			border: none;
			icon-size: 22px;
			max-height: 26px;
			min-height: 26px;
			min-width: 26px;
			max-width: 26px;
		""")


from __future__ import annotations
from DTPySide import *

class DTMainSession(DTFrame.DTMainWindow):
	"""DTAPP的主程序
	通过DTAPP.setMainSession(DTMainSession)传入DTAPP
	相当于Qt程序最初的QMainWindow

	Args:
		DTMainWindow (这是啥): 这里要填啥

	Returns:
		没有return: 这里要填啥
	"""	

	def __init__(self, app):
		"""DTMainSession的构造函数

		Args:
			app (DTAPP): 保存传入的app指针
		"""
		
		super().__init__(app)

		self.haveTanslation=hasattr(self.app,"translation")
			
	
	def initialize(self):
		if self.haveTanslation==False and hasattr(self.app,"translation")==True:
			raise("You Must load the translation module before the construction of MainSession!")
		else:
			del self.haveTanslation
		
		self.initializeData()
		self.initializeWindow()
		self.restoreWindowStatus()

		self.initializeSignal()
		self.initializeMenu()
	
	def dataValidityCheck(self):
		return True
	
	def initializeData(self):
		if self.dataValidityCheck():
			self.loadData()
		else:
			DTFrame.DTMessageBox(self,"Error","Data is not valid!")
			self.app.quit()

	def restoreWindowStatus(self):
		"""MainSession中在这里恢复WindowStatu
		"""	
		
		try:
			self.resize(self.UserSetting().value("WindowStatus/Size"))
			self.move(self.UserSetting().value("WindowStatus/Pos"))
		except:
			self.resize(self.minimumWidth(),self.minimumHeight())
			self.adjustSize()
			MoveToCenterOfScreen(self)
	
	def initializeSignal(self):
		"""主窗体的action向function链接
		注意：需要拥有全局快捷键的action，需要addAction
		"""
		super().initializeSignal()
		
		self.actionExit.triggered.connect(self.quit)
		if self.app.isQuitOnClickX():
			self.TitleBar.btn_close.clicked.connect(self.quit)
		else:
			self.TitleBar.btn_close.clicked.connect(self.close)

		self.actionSetting.triggered.connect(self.setting)
		self.actionAbout.triggered.connect(self.about)
		self.actionBoss_Key.triggered.connect(self.bossComing)
		self.addAction(self.actionBoss_Key)

		if self.app.isBackupEnable():
			self.actionBackup.triggered.connect(self.backup)
	
	def initializeMenu(self):
		"制定menu"

		if self.app.isBackupEnable():
			self._MainMenu.addAction(self.actionBackup)
			self._MainMenu.addSeparator()
		
		################################################################

		self._MainMenu.addAction(self.actionSetting)
		self._MainMenu.addAction(self.actionAbout)
		self._MainMenu.addSeparator()
		
		################################################################
		
		self.__menu_view=QMenu(QCoreApplication.translate("DTMainWindow","View"),self) #这里不能用self.tr，因为如果被继承了，这里的self将会是子类，而在qm翻译文件的context中记录的是DTMainSWindow的翻译
		self.__menu_view.setIcon(IconFromCurrentTheme("eye.svg"))
		self.__menu_view.addAction(self.actionWindow_Toggle_Stay_on_Top)
		self.__menu_view.addAction(self.actionWindow_Toggle_Fullscreen)
		self.__menu_view.addAction(self.actionNormalize_Window)
		self.__menu_view.addAction(self.actionMinimize_Window)
		self.__menu_view.addAction(self.actionMaximize_Window)
		self.addMenuToMainMenu(self.__menu_view)
		
		self._MainMenu.addAction(self.actionBoss_Key)
		self._MainMenu.addAction(self.actionExit)
		
	def refresh(self):
		""""改变颜色后，可能有些依赖于app.color_list的颜色要更新，在这里添加对所有窗体的刷新操作"
		"""
		pass
	
	def windowResurrection(self,reason):
		"双击TrayIcon还原主窗体"
		
		from DTPySide import DTSession
		# 必须在这里再调用一次，如果不写的话，下面会说name 'DTSession' is not defined。不知道为什么啊啊啊，明明都在DTPySide的__init__中导入过了呀？！难道又是同级包内互相调用的问题，还是__feature__的annotation暂时还有bug？

		if reason==QSystemTrayIcon.DoubleClick:
			if self.isHidden():
				# 有Login选项
				if self.app.isLoginEnable():

					# 还未出现Login界面
					if not hasattr(self,"ResurrectionDlg"):
						self.ResurrectionDlg=DTSession.DTLoginSession(self.UserSetting().value("BasicInfo/Password"))

						#成功登回
						if self.ResurrectionDlg.exec_():
							self.show()
							# 恢复self._MainMenu里的其他action
							for action in self._MainMenu.actions()[:-1]:
								action.setVisible(True)
						
						del self.ResurrectionDlg
					
					# 已经有Login界面了
					else:
						pass
				
				# 无Login选项
				else:
					self.show()
			
			# 
			else:
				self.show()
	
	def bossComing(self):
		self.hide()
		
		if self.app.isLoginEnable():
			# Boss键后只显示退出键，self._MainMenu里的其他action隐藏掉
			for action in self._MainMenu.actions()[:-1]:
				action.setVisible(False)
	
	def loadData(self):
		"""这里请用self.app.DataDir获取Data的路径
		"""
		pass

	def saveData(self):
		"""这里请用self.app.DataDir获取Data的路径
		"""
		pass
	
	def saveWindowStatus(self):
		self.UserSetting().setValue("WindowStatus/Size",self.size())
		self.UserSetting().setValue("WindowStatus/Pos",self.pos())
	
	def saveAllEncryptData(self):
		"saveData或者UserSetting中有加密的保存项目就要放到这里（更改密码的时候会调用这个函数）"
		if self.app.DataDir()!=None:
			self.app.setDataDir(self.app.DataDir())
		if self.app.isBackupEnable() and self.app.BackupDst()!=None:
			self.app.setBackupDst(self.app.BackupDst())
		
	def backup(self):
		# 可以implement这个函数，比如先保存一下

		class BackUpThread(QThread):
			def __init__(self, parent, data_dir, data_list):
				super().__init__(parent=parent)
				self.data_dir=data_dir
				self.data_list=data_list
			
			def run(self):
				if not os.path.exists(new_folder_dst):
					os.makedirs(new_folder_dst)
				for file in self.data_list:
					file_dst=os.path.join(new_folder_dst,file)
					shutil.copyfile(os.path.join(self.data_dir,file),file_dst)
		
		backup_dst=self.app.BackupDst()
		if backup_dst==None:
			DTFrame.DTMessageBox(self,"Warning","Please set backup dst first!",DTIcon.Warning())
		elif not os.path.exists(backup_dst):
			DTFrame.DTMessageBox(self,"Warning","Backup Dst %s does not exsit!"%backup_dst,DTIcon.Warning())
		else:
			new_folder_dst=os.path.join(backup_dst,WhatDayIsToday(1).toString("yyyyMMdd")).replace("/","\\")
			self.backup_thread=BackUpThread(self, self.app.DataDir(), self.app.DataList())
			self.backup_thread.finished.connect(self.backup_thread.deleteLater)
			self.backup_thread.finished.connect(lambda:self.app.showMessage("Information", "Data backup completed.", DTIcon.Information(), clicked_slot=lambda:os.popen("explorer /select,\"%s\""%new_folder_dst)))
			self.backup_thread.start()

	def about(self):
		about_text=""
		
		self.UserSetting().beginGroup("MetaData")
		for key in self.UserSetting().allKeys():
			about_text+="%s: %s\n"%(key,self.UserSetting().value(key))
		self.UserSetting().endGroup()

		DTFrame.DTMessageBox(self,"About",about_text[:-1],icon=DTIcon.Holo01())
	
	def setting(self):
		"请在继承的DTSettingSession中做到实时保存设定"
		
		from DTPySide import DTSession
		# 必须在这里再调用一次，如果不写的话，下面会说name 'DTSession' is not defined。不知道为什么啊啊啊，明明都在DTPySide的__init__中导入过了呀？！难道又是同级包内互相调用的问题，还是__feature__的annotation暂时还有bug？
		
		dlg=DTSession.DTSettingSession(self, self.app)
		dlg.exec_()
	
	def quit(self):
		self.saveWindowStatus()
		self.saveData()
		self.app.quit()


from __future__ import annotations

import importlib.metadata
__version__ = importlib.metadata.version('DTPySide')

from DTPySide.DTFunction import *
from DTPySide.DTStyleSheet import DTStyleSheet

import DTPySide.DTIcon as DTIcon

import DTPySide.DTWidget as DTWidget
import DTPySide.DTFrame as DTFrame
import DTPySide.DTModule as DTModule
import DTPySide.DTTranslation as DTTranslation

import DTPySide.DTSession as DTSession
from DTPySide.DTAPP import DTAPP


from __future__ import annotations
from DTPySide import *

# Login 
class DTLoginSession(DTFrame.DTDialog):
	def __init__(self,locked_password,title="Login"):
		super().__init__(None,title)
		self.__LoginModule=DTModule.DTLogin(self)
		self.centralWidget.setContentsMargins(QMargins(9,10,32,10))
		self.setCentralWidget(self.__LoginModule)
		self.setWindowTitle(title)
		self.buttonBox.button(QDialogButtonBox.Ok).setDefault(True)

		# 获取UserSetting.ini中的加密密码
		self.locked_password=locked_password
		
		#欢迎新用户
		if not self.locked_password:
			self.__LoginModule.label_lock.setPixmap(DTIcon.Happy().pixmap(QSize(64,64)))
		
		self.setFocus()
		self.__LoginModule.lineEdit.setFocus()
	
	def accept(self):

		self.__LoginModule.lineEdit.setReadOnly(True)
		self.input_password=self.__LoginModule.lineEdit.text()
		
		#新用户
		if not self.locked_password:
			self.__LoginModule.label_lock.setPixmap(DTIcon.Lock().pixmap(QSize(64,64)))
			Delay_Msecs(400)
			self.__LoginModule.label_lock.setPixmap(DTIcon.Unlock().pixmap(QSize(64,64)))
			Delay_Msecs(600)
			super().accept()
		
		elif Fernet_Decrypt(self.input_password,self.locked_password)==self.input_password:
			self.__LoginModule.label_lock.setPixmap(DTIcon.Lock().pixmap(QSize(64,64)))
			Delay_Msecs(400)
			self.__LoginModule.label_lock.setPixmap(DTIcon.Unlock().pixmap(QSize(64,64)))
			Delay_Msecs(600)
			super().accept()
		else:
			self.__LoginModule.label_lock.setPixmap(DTIcon.Unhappy().pixmap(QSize(64,64)))
			self.__LoginModule.lineEdit.setReadOnly(False)
	
	def reject(self):
		super().reject()